==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/igr-range-category-series.js <==
import { __extends } from "tslib";
import { IgrCategorySeries } from "./igr-category-series";
/**
 * Represents the base class for all IgxDataChartComponent ranged category/value series.
*
* The `RangeCategorySeries` represents the base class for all IgxDataChartComponent ranged category/value series.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrRangeColumnSeries
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series1 = new IgrRangeColumnSeries({ name: "series1" });
* series1.highMemberPath = "High";
* series1.lowMemberPath  = "Low";
* series1.xAxisName = "xAxis";
* series1.yAxisName = "yAxis";
* this.chart.series.add(series1);
* ```
*/
var IgrRangeCategorySeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRangeCategorySeries, _super);
    function IgrRangeCategorySeries(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrRangeCategorySeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeCategorySeries.prototype, "lowMemberPath", {
        /**
         * Gets or sets the value mapping property for the current series object.
        *
        * The `LowMemberPath` is used for low mapping property of the current series object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *     <IgrCategoryXAxis name="xAxis" label="Year" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *     <IgrRangeColumnSeries
        *         name="series1"
        *         xAxisName="xAxis"
        *         yAxisName="yAxis"
        *         highMemberPath="High"
        *         lowMemberPath="Low" />
        *  </IgrDataChart>
        * ```
        *
        * ```ts
        * const series1 = new IgrRangeColumnSeries({ name: "series1" });
        * series1.highMemberPath = "High";
        * series1.lowMemberPath  = "Low";
        * ```
        */
        get: function () {
            return this.i.aap;
        },
        set: function (v) {
            this.i.aap = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeCategorySeries.prototype, "highMemberPath", {
        /**
         * Gets or sets the value mapping property for the current series object.
        *
        * Use `HighMemberPath` propert for high mapping of the current series object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *     <IgrCategoryXAxis name="xAxis" label="Year" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *     <IgrRangeColumnSeries
        *         name="series1"
        *         xAxisName="xAxis"
        *         yAxisName="yAxis"
        *         highMemberPath="High"
        *         lowMemberPath="Low" />
        *  </IgrDataChart>
        * ```
        *
        * ```ts
        * series.highMemberPath = "high";
        * ```
        *
        * ```ts
        * const series1 = new IgrRangeColumnSeries({ name: "series1" });
        * series1.highMemberPath = "High";
        * series1.lowMemberPath  = "Low";
        * ```
        */
        get: function () {
            return this.i.aam;
        },
        set: function (v) {
            this.i.aam = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeCategorySeries.prototype, "highlightedLowMemberPath", {
        /**
         * Gets or sets the highlighted low value mapping property for the current series object.
        */
        get: function () {
            return this.i.aak;
        },
        set: function (v) {
            this.i.aak = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeCategorySeries.prototype, "highlightedHighMemberPath", {
        /**
         * Gets or sets the highlighted High value mapping property for the current series object.
        */
        get: function () {
            return this.i.aai;
        },
        set: function (v) {
            this.i.aai = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrRangeCategorySeries.prototype.getItemValue = function (item, memberPathName) {
        var iv = this.i.ko(item, memberPathName);
        return (iv);
    };
    /**
     * Gets the value of a requested member path from the series.
    
    * @param memberPathName  * The property name of a valid member path for the series
    */
    IgrRangeCategorySeries.prototype.getMemberPathValue = function (memberPathName) {
        var iv = this.i.ma(memberPathName);
        return (iv);
    };
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    *
    * `ScrollIntoView` method Scrolls the series to display the item for the specified data item.
    */
    IgrRangeCategorySeries.prototype.scrollIntoView = function (item) {
        var iv = this.i.gb(item);
        return (iv);
    };
    return IgrRangeCategorySeries;
}(IgrCategorySeries));
export { IgrRangeCategorySeries };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/igr-range-category-series.js <==
import { __extends } from "tslib";
import { IgrCategorySeries } from "./igr-category-series";
/**
 * Represents the base class for all IgxDataChartComponent ranged category/value series.
*
* The `RangeCategorySeries` represents the base class for all IgxDataChartComponent ranged category/value series.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrRangeColumnSeries
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series1 = new IgrRangeColumnSeries({ name: "series1" });
* series1.highMemberPath = "High";
* series1.lowMemberPath  = "Low";
* series1.xAxisName = "xAxis";
* series1.yAxisName = "yAxis";
* this.chart.series.add(series1);
* ```
*/
var IgrRangeCategorySeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRangeCategorySeries, _super);
    function IgrRangeCategorySeries(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrRangeCategorySeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeCategorySeries.prototype, "lowMemberPath", {
        /**
         * Gets or sets the value mapping property for the current series object.
        *
        * The `LowMemberPath` is used for low mapping property of the current series object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *     <IgrCategoryXAxis name="xAxis" label="Year" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *     <IgrRangeColumnSeries
        *         name="series1"
        *         xAxisName="xAxis"
        *         yAxisName="yAxis"
        *         highMemberPath="High"
        *         lowMemberPath="Low" />
        *  </IgrDataChart>
        * ```
        *
        * ```ts
        * const series1 = new IgrRangeColumnSeries({ name: "series1" });
        * series1.highMemberPath = "High";
        * series1.lowMemberPath  = "Low";
        * ```
        */
        get: function () {
            return this.i.aa7;
        },
        set: function (v) {
            this.i.aa7 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeCategorySeries.prototype, "highMemberPath", {
        /**
         * Gets or sets the value mapping property for the current series object.
        *
        * Use `HighMemberPath` propert for high mapping of the current series object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *     <IgrCategoryXAxis name="xAxis" label="Year" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *     <IgrRangeColumnSeries
        *         name="series1"
        *         xAxisName="xAxis"
        *         yAxisName="yAxis"
        *         highMemberPath="High"
        *         lowMemberPath="Low" />
        *  </IgrDataChart>
        * ```
        *
        * ```ts
        * series.highMemberPath = "high";
        * ```
        *
        * ```ts
        * const series1 = new IgrRangeColumnSeries({ name: "series1" });
        * series1.highMemberPath = "High";
        * series1.lowMemberPath  = "Low";
        * ```
        */
        get: function () {
            return this.i.aa4;
        },
        set: function (v) {
            this.i.aa4 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeCategorySeries.prototype, "highlightedLowMemberPath", {
        /**
         * Gets or sets the highlighted low value mapping property for the current series object.
        */
        get: function () {
            return this.i.aa2;
        },
        set: function (v) {
            this.i.aa2 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeCategorySeries.prototype, "highlightedHighMemberPath", {
        /**
         * Gets or sets the highlighted High value mapping property for the current series object.
        */
        get: function () {
            return this.i.aa0;
        },
        set: function (v) {
            this.i.aa0 = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrRangeCategorySeries.prototype.getItemValue = function (item, memberPathName) {
        var iv = this.i.kq(item, memberPathName);
        return (iv);
    };
    /**
     * Gets the value of a requested member path from the series.
    
    * @param memberPathName  * The property name of a valid member path for the series
    */
    IgrRangeCategorySeries.prototype.getMemberPathValue = function (memberPathName) {
        var iv = this.i.md(memberPathName);
        return (iv);
    };
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    *
    * `ScrollIntoView` method Scrolls the series to display the item for the specified data item.
    */
    IgrRangeCategorySeries.prototype.scrollIntoView = function (item) {
        var iv = this.i.gd(item);
        return (iv);
    };
    return IgrRangeCategorySeries;
}(IgrCategorySeries));
export { IgrRangeCategorySeries };
